@@ -24,10 +24,19 @@ import gettext
 gettext.install("ibus-libpinyin")
 
 def get_version():
-    return "1.12.1"
+    return "1.16.5"
 
 def get_longname():
     return _("Intelligent Pinyin")
 
 def support_cloud_input():
     return False
+
+def enable_lua_extension():
+    return True
+
+def enable_table_mode():
+    return True
+
+def enable_english_input_mode():
+    return True
